Module errors
explore
0.0.3
Module errors
Module Items
Functions
In crate explore
explore
Module
errors
Functions

install_
hooks
This replaces the standard color_eyre panic and error hooks with hooks that restore the terminal before printing the panic or error.